@@ -58,3 +58,6 @@ SCHEDULE_TIMEZONE = Literal['Local', 'Utc']
 SWITCH_ENVIRONMENT = Literal['Development', 'Staging', 'Testing', 'Production']
 
 SUPPORT_PAYLOAD_TYPE = Literal['Sites', 'Sensors', 'Portfolio']
+
+INTEGRATION_SETTINGS_EDITORS = Literal['text_box', 'numeric_stepper', 'custom_combo', 'tag_groups_combo',
+                                       'equipment_combo']
