@@ -10,6 +10,7 @@ A module for .....
 import re
 import uuid
 from collections import namedtuple
+from typing import Union
 import string
 import secrets
 import pandas
@@ -80,10 +81,15 @@ def _is_valid_regex(regex):
         return False
 
 
-ApiInputs = namedtuple('ApiInputs',
-                       ['auth', 'email_address', 'user_id', 'api_key', 'api_project_id', 'datacentre', 'db_name',
-                        'data_feed_id', 'data_feed_file_status_id'])
+ApiHeaders = namedtuple('ApiHeaders', ['default', 'integration'])
 
+ApiInputs = namedtuple('ApiInputs',
+                       ['email_address', 'user_id', 'api_project_id', 'data_feed_id', 'data_feed_file_status_id',
+                        'bearer_token', 'api_base_url', 'api_projects_endpoint', 'subscription_key', 'api_headers'])
+
+DiscoveryIntegrationInput = namedtuple(
+        'DiscoveryIntegrationInput',
+        ['api_project_id', 'installation_id', 'network_device_id', 'integration_device_id', 'user_id', 'batch_no'])
 
 DataFeedFileProcessOutput = namedtuple('DataFeedFileProcessOutput',
                                        [
@@ -136,6 +142,45 @@ def convert_to_sqm(df: pandas.DataFrame, sqft_col_name: str):
     return df
 
 
+# def convert_to_pascal_case(text: str):
+#     text = re.sub(r"^[\-_:\.\s]", '', str(text))
+#     text = str.upper(text[0]) + text[1:]
+#     if not text:
+#         return text
+#     text = re.sub(r"[\-_:\.\s]([a-z])", lambda matched: str.upper(matched.group(1)), text)
+#     return re.sub(r"[\-_:\.\s]", '', text)
+#
+#     # return lowercase(text[0]) + re.sub(r"[\-_\.\s]([a-z])", lambda matched: uppercase(matched.group(1)), text[1:])
+#     # str(text).upper()
+#     #
+#     # text = re.sub(r"^[\-_\.]", '', str(lowercase(text)))
+#     # if not text:
+#     #     return text
+#     # return lowercase(text[0]) + re.sub(r"[\-_\.\s]([a-z])", lambda matched: uppercase(matched.group(1)), text[1:])
+
+
+def convert_to_pascal_case(text: Union[str,list]):
+    if type(text) == str:
+        text = re.sub(r"^[\-_:\.\s]", '', str(text))
+        text = str.upper(text[0]) + text[1:]
+        if not text:
+            return text
+        text = re.sub(r"[\-_:\.\s]([a-z])", lambda matched: str.upper(matched.group(1)), text)
+        return re.sub(r"[\-_:\.\s]", '', text)
+    elif type(text) == list:
+        for i in range(len(text)):
+            text_item = text[i]
+
+            text_item = re.sub(r"^[\-_:\.\s]", '', str(text_item))
+            text_item = str.upper(text_item[0]) + text_item[1:]
+            if not text_item:
+                text[i] = text_item
+            text_item = re.sub(r"[\-_:\.\s]([a-z])", lambda matched: str.upper(matched.group(1)), text_item)
+
+            text[i] = re.sub(r"[\-_:\.\s]", '', text_item)
+        return text
+
+
 _site_schema = pandera.DataFrameSchema(
     {
         'InstallationName': pandera.Column(pandera.String, checks=pandera.Check.str_length(1, 255)),
