@@ -44,19 +44,17 @@ def get_folders(api_inputs: ApiInputs, folder_type="dataset"):
         (response, df) - Returns the response status of the call & a dataframe containing the data returned by the call.
 
     """
-    payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
 
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Folders/FolderType/" + folder_type
+    payload = {}
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/folders?type={folder_type}"
     logger.info("Sending request: GET %s", url)
+
     response = requests.request("GET", url, data=payload, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -64,7 +62,7 @@ def get_folders(api_inputs: ApiInputs, folder_type="dataset"):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
     df = pandas.read_json(response.text)
     logger.info("API Call successful.")
@@ -93,19 +91,20 @@ def get_datasets_list(api_inputs: ApiInputs, include_path: bool = False, path_pr
         (response, df) - Returns the response status of the call & a dataframe containing the data returned by the call.
 
     """
-    payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Datasets/PathPrefix/" + \
-        path_prefix.replace('/', '|') + "/IncludePath/" + str(include_path)
+    payload = {}
+    headers = api_inputs.api_headers.default
+
+    if(path_prefix != "*"):
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/datasets?pathprefix={path_prefix.replace('/', '|')}&includepath={str(include_path)}"
+    else:
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/datasets?includepath={str(include_path)}"
+
+    logger.info("Sending request: GET %s", url)
+
     response = requests.request("GET", url, data=payload, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -113,7 +112,7 @@ def get_datasets_list(api_inputs: ApiInputs, include_path: bool = False, path_pr
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
@@ -141,18 +140,15 @@ def get_data(api_inputs: ApiInputs, dataset_id, parameters: dict = None):
     tuple[str, pandas.DataFrame]
         (response, df) - Returns the response status of the call & a dataframe containing the data returned by the call.
     """
-    # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
 
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/DatasetData/" + str(dataset_id)
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/datasets/queries/{str(dataset_id)}/data"
+    logger.info("Sending request: POST %s", url)
     logger.info('DataSets: Sending request for DatasetID: %s', dataset_id)
 
     if parameters is None:
@@ -164,7 +160,7 @@ def get_data(api_inputs: ApiInputs, dataset_id, parameters: dict = None):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('DataSets: no data returned for this call. %s', response.request.__dict__)
+        logger.error('DataSets: no data returned for this call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text, dtype=False)
