@@ -7,17 +7,15 @@
 A module containing the helper functions useful when integrating asset creation, asset updates, data ingestion, etc
 into the Switch Automation platform.
 """
+import json
 import sys
 import pandas
-# import pandera
 import requests
-# import datetime
 import logging
 import uuid
 from typing import Union
-# from .._utils._platform import _get_structure, Blob
 from .._utils._constants import api_prefix, QUERY_LANGUAGE
-from .._utils._utils import ApiInputs, _column_name_cap  # , _with_func_attrs, _work_order_schema
+from .._utils._utils import ApiInputs, _column_name_cap
 
 logger = logging.getLogger(__name__)
 logger.setLevel(logging.DEBUG)
@@ -47,19 +45,16 @@ def get_operation_state(upload_id: uuid.UUID, api_inputs: ApiInputs):
 
     """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
+    headers = api_inputs.api_headers.default
+
     # upload Blobs to folder
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.db_name + "/" + api_inputs.api_project_id + \
-        "/AdxDataOperation/" + upload_id
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/adx/operation-state?operationId={upload_id}"
+    logger.info("Sending request: GET %s", url)
+
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -67,7 +62,7 @@ def get_operation_state(upload_id: uuid.UUID, api_inputs: ApiInputs):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
@@ -90,7 +85,7 @@ def load_data(dev_mode_path, api_inputs: ApiInputs):
     pandas.DataFrame
 
     """
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_projects_endpoint == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
@@ -116,18 +111,14 @@ def data_table_exists(table_name: str, api_inputs: ApiInputs):
 
     """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.db_name + "/" + api_inputs.api_project_id + \
-        "/DataTableExists/" + table_name
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/adx/table?name={table_name}"
+    logger.info("Sending request: GET %s", url)
 
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
@@ -136,7 +127,7 @@ def data_table_exists(table_name: str, api_inputs: ApiInputs):
                      response.reason)
         return response_status
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status
 
     if response.text == 'true':
@@ -196,18 +187,14 @@ def get_sites(api_inputs: ApiInputs, include_tag_groups: Union[list, bool] = Fal
         "topCount": top_count,
     }
 
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-        "/Integration/GetSites"
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/installations/sites-ingestion"
+    logger.info("Sending request: POST %s", url)
 
     response = requests.post(url, json=payload, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
@@ -216,7 +203,7 @@ def get_sites(api_inputs: ApiInputs, include_tag_groups: Union[list, bool] = Fal
                      response.reason)
         return response_status
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status
 
     df = pandas.read_json(response.text)
@@ -260,9 +247,16 @@ def get_device_sensors(api_inputs: ApiInputs, include_tag_groups: Union[list, bo
                          'or include_metadata_keys to False. ')
         return
 
+    limit = 50000
+    offset = 0
+    is_finished = False
+
     if top_count is None:
         top_count = 0
 
+    if top_count > 0:
+        limit = 0
+
     tags_mode = False
     tag_groups = []
     if type(include_tag_groups) is list:
@@ -288,35 +282,59 @@ def get_device_sensors(api_inputs: ApiInputs, include_tag_groups: Union[list, bo
         "includeMetadataColumns": metadata_keys,
         "sqlWhereClause": sql_where_clause,
         "topCount": top_count,
+        "limit": limit,
+        "offset": offset
     }
 
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + \
-        "/Integration/GetDeviceSensors"
+    headers = api_inputs.api_headers.default
 
-    response = requests.post(url, json=payload, headers=headers)
-    response_status = '{} {}'.format(response.status_code, response.reason)
-    if response.status_code != 200:
-        logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
-                     response.reason)
-        return response_status
-    elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
-        return response_status
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/devices/device-sensors"
+    logger.info("Sending request: POST %s", url)
 
-    df = pandas.read_json(response.text, dtype=False)
-    df.rename(columns={"InstallationID": "InstallationId", "ObjectPropertyID": "ObjectPropertyId"}, inplace=True)
+    df_master = pandas.DataFrame()
+    # holder of paginated dataframes
+    df_data_chunks = []
+    # Loop through pagination until encountered error message or empty Next URL
+    while is_finished == False:
+        df_data = ''
+        # df_message = ''
 
-    return df
+        response = requests.post(url, json=payload, headers=headers)
+        response_status = '{} {}'.format(response.status_code, response.reason)
+
+        if response.status_code != 200:
+            logger.error("API Call was not successful. Response Status: %s. Reason: %s.", response.status_code,
+                         response.reason)
+            return response_status
+        elif len(response.text) == 0:
+            logger.error('No data returned for this API call. %s', response.request.url)
+            return response_status
+
+        response_dict = json.loads(response.text)
+
+        if 'Message' in response_dict.keys() and len(response_dict['Message']) != 0 and response_dict['Message'] != '':
+            logger.error(response_dict['Message'])
+            is_finished = True
+            return response_status, response_dict['Message']
+
+        if 'Data' in response_dict.keys() and len(response_dict['Data']) != 0:
+            df_data = pandas.DataFrame(response_dict['Data'])
+            df_data_chunks.append(df_data)
+
+        if 'NextUrl' in response_dict.keys() and len(response_dict['NextUrl']) != 0:
+            payload = json.loads(response_dict['NextUrl'])
+        else:
+            is_finished = True
+            df_master = pandas.concat(df_data_chunks, ignore_index=True)
+            df_master.rename(columns={"InstallationID": "InstallationId", "ObjectPropertyID": "ObjectPropertyId"},
+                           inplace=True)
+            return df_master
+
+    return df_master
 
 
 def get_data(query_text, api_inputs: ApiInputs, query_language: QUERY_LANGUAGE = "sql"):
@@ -340,23 +358,21 @@ def get_data(query_text, api_inputs: ApiInputs, query_language: QUERY_LANGUAGE =
         "queryText": query_text,
         "queryLanguage": str(query_language)
     }
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
 
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
+    headers = api_inputs.api_headers.default
+
     if not set([query_language]).issubset(set(QUERY_LANGUAGE.__args__)):
         logger.error('query_language parameter must be set to one of the allowed values defined by the '
                      'QUERY_LANGUAGE literal: %s', QUERY_LANGUAGE.__args__)
         return False
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.db_name + "/" + api_inputs.api_project_id + \
-        "/Integration/GetData"
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/adx/data"
+    logger.info("Sending request: POST %s", url)
+
     response = requests.post(url, json=payload, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -364,7 +380,7 @@ def get_data(query_text, api_inputs: ApiInputs, query_language: QUERY_LANGUAGE =
                      response.reason)
         return response_status
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status
 
     df = pandas.read_json(response.text)
@@ -389,17 +405,15 @@ def get_states_by_country(api_inputs: ApiInputs, country: str):
 
         """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + "Country/States/" + country
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_base_url}/country/{country}/states"
+    logger.info("Sending request: GET %s", url)
+
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -407,7 +421,7 @@ def get_states_by_country(api_inputs: ApiInputs, country: str):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
@@ -435,21 +449,20 @@ def get_templates(api_inputs: ApiInputs, object_property_type: str = None):
 
     """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
+    headers = api_inputs.api_headers.default
+
     url = ''
     if object_property_type is None:
-        url = api_prefix + "Templates"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/templates"
     elif object_property_type is not None:
-        url = api_prefix + 'TemplatesByType/' + object_property_type
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/templates?type={object_property_type}"
+
+    logger.info("Sending request: GET %s", url)
+
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -457,7 +470,7 @@ def get_templates(api_inputs: ApiInputs, object_property_type: str = None):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
@@ -481,17 +494,15 @@ def get_tag_groups(api_inputs: ApiInputs):
 
     """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Tags"
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/tags/tag-groups"
+
+    logger.info("Sending request: GET %s", url)
 
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
@@ -500,7 +511,7 @@ def get_tag_groups(api_inputs: ApiInputs):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
@@ -524,17 +535,14 @@ def get_metadata_keys(api_inputs: ApiInputs):
 
     """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
-
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + api_inputs.datacentre + "/" + api_inputs.api_project_id + "/Metadata"
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/metadata/all-type"
+    logger.info("Sending request: GET %s", url)
 
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
@@ -543,7 +551,7 @@ def get_metadata_keys(api_inputs: ApiInputs):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
@@ -569,21 +577,21 @@ def get_units_of_measure(api_inputs: ApiInputs, object_property_type: str = None
 
     """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
 
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
+    headers = api_inputs.api_headers.default
+
     url = ''
+
     if object_property_type is None:
-        url = api_prefix + "Units"
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/units"
     elif object_property_type is not None:
-        url = api_prefix + 'UnitsByType/' + object_property_type
+        url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/data-ingestion/units?type={object_property_type}"
+
+    logger.info("Sending request: GET %s", url)
 
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
@@ -592,7 +600,7 @@ def get_units_of_measure(api_inputs: ApiInputs, object_property_type: str = None
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
@@ -616,17 +624,20 @@ def get_equipment_classes(api_inputs: ApiInputs):
 
     """
     # payload = {}
-    headers = {
-        'x-functions-key': api_inputs.api_key,
-        'Content-Type': 'application/json; charset=utf-8',
-        'user-key': api_inputs.user_id
-    }
+    if (api_inputs.api_base_url == '' or api_inputs.bearer_token == ''):
+        logger.error("You must call initialize() before using API.")
+        return pandas.DataFrame()
 
-    if api_inputs.datacentre == '' or api_inputs.api_key == '':
+    headers = api_inputs.api_headers.default
+
+    url = f"{api_inputs.api_projects_endpoint}/{api_inputs.api_project_id}/installation/00000000-0000-0000-0000-000000000000/equipment/integration-classes"
+
+    logger.info("Sending request: GET %s", url)
+
+    if (api_inputs.api_projects_endpoint == '' or api_inputs.bearer_token == ''):
         logger.error("You must call initialize() before using API.")
         return pandas.DataFrame()
 
-    url = api_prefix + "EquipmentClasses"
     response = requests.request("GET", url, timeout=20, headers=headers)
     response_status = '{} {}'.format(response.status_code, response.reason)
     if response.status_code != 200:
@@ -634,7 +645,7 @@ def get_equipment_classes(api_inputs: ApiInputs):
                      response.reason)
         return response_status, pandas.DataFrame()
     elif len(response.text) == 0:
-        logger.error('No data returned for this API call. %s', response.request.__dict__)
+        logger.error('No data returned for this API call. %s', response.request.url)
         return response_status, pandas.DataFrame()
 
     df = pandas.read_json(response.text)
@@ -642,7 +653,6 @@ def get_equipment_classes(api_inputs: ApiInputs):
 
     return df
 
-
 # def get_portfolios(api_inputs: ApiInputs, search_term: str = None):
 #     """Get list of units of measure by type.
 #
@@ -681,7 +691,7 @@ def get_equipment_classes(api_inputs: ApiInputs):
 #                      response.reason)
 #         return response_status, pandas.DataFrame()
 #     elif len(response.text) == 0:
-#         logger.error('No data returned for this API call. %s', response.request.__dict__)
+#         logger.error('No data returned for this API call. %s', response.request.url)
 #         return response_status, pandas.DataFrame()
 #
 #     df = pandas.read_json(response.text)
