@@ -97,7 +97,7 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
         return 'Integration.upsert_discovered_records(): data_frame must contain the following discovery property' \
                ' columns: ' + ', '.join(discovery_properties_columns)
 
-    if device_tag_columns is not None and not set(tag_columns).issubset(data_frame.columns):
+    if device_tag_columns is not None and not set(device_tag_columns).issubset(data_frame.columns):
         logger.exception('Missing expected device tag column(s): %s',
                          set(device_tag_columns).difference(proposed_columns))
         return 'Integration.upsert_discovered_records(): data_frame expected to contain the following device tag ' \
@@ -105,7 +105,7 @@ def upsert_discovered_records(df: pandas.DataFrame, api_inputs: ApiInputs, disco
     elif device_tag_columns is None:
         device_tag_columns = []
 
-    if sensor_tag_columns is not None and not set(tag_columns).issubset(data_frame.columns):
+    if sensor_tag_columns is not None and not set(sensor_tag_columns).issubset(data_frame.columns):
         logger.exception('Missing expected sensor tag column(s): %s',
                          set(sensor_tag_columns).difference(proposed_columns))
         return 'Integration.upsert_discovered_records(): data_frame expected to contain the following sensor tag ' \
